@@ -1,4 +1,4 @@
-__version__ = "TinyWebIO v0.0.7"
+__version__ = "TinyWebIO v0.0.8"
 __author__ = "roadlabs@gmail.com"
 __license__ = "http://unlicense.org"
 
@@ -52,15 +52,22 @@ class Request:
                             break
             cmd = firstline.split()
             self.method = cmd[0]
-            self.path = cmd[1]
+            _path = cmd[1].split('?', 1)
+            if len(_path) > 1:
+                self.method = 'POST'
+                self._set_form(_path[-1])
+            self.path = _path[0]
             if len(lastline) > 0:
-                params = lastline.split('&')
-                for p in params:
-                    k, v = p.split('=')
-                    self.form[k] = v.strip('"')
+                self._set_form(lastline)
         except Exception as e:
             print("request data parsed failure!:%s" % e)
 
+    def _set_form(self, data):
+        params = data.split('&')
+        for p in params:
+            k, v = p.split('=')
+            self.form[k] = v.strip('"')
+
 
 class Response:   
     def __init__(self, socket=None):
